#
# spec file for package commandergenius
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           commandergenius
Version:        3.5.2
Release:        1.2
Summary:        A clone of the Commander Keen engines
License:        GPL-2.0-only
Group:          Amusements/Games/Action/Arcade
URL:            http://clonekeenplus.sf.net/
#Git-Clone:     https://gitlab.com/Dringgstein/Commander-Genius
Source:         https://gitlab.com/Dringgstein/Commander-Genius/-/archive/v%version/Commander-Genius-v%version.tar.bz2
Patch1:         fix-icons.patch
Patch2:         gs.patch
BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_image) >= 2.0.0
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%description
Commander Genius is a software piece that interprets the Commander
Keen Vorticon (1-3) and Galaxy (3½-6) series.

It has 4-player cooperative mode and six difficulty modes.

%prep
%autosetup -p1 -n Commander-Genius-v%version
if pkg-config 'SDL2_ttf < 2.24'; then
%patch -P 2 -R -p1
fi

%build
%cmake \
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DAPPDIR="%_bindir"
%cmake_build

%install
%cmake_install
install -Dm0644 share/cg.svg "%buildroot/%_datadir/icons/hicolor/scalable/apps/cg.svg"
%fdupes %buildroot/%_datadir

%files
%license COPYRIGHT
%_bindir/CGeniusExe
%_datadir/applications/cgenius.desktop
%_datadir/metainfo/io.sourceforge.clonekeenplus.appdata.xml
%_datadir/icons/hicolor/
%_datadir/games/%name/

%changelog
* Sun Jan 26 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.2
  * No changelog was provided
* Fri Jan 17 2025 Jan Engelhardt <jengelh@inai.de>
- Add gs.patch to fix FTBFS
* Wed Jul 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.1
  * No changelog was provided
* Sat Nov 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5.0
  * Build fixes for non-Linux systems
* Mon Aug 28 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.4.9
  * No changelog was provided
* Thu Jul 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4.0
  * New Resolution system. You can configure a relative resolution
    for the launcher but also for every game.
- Update to version 3.3.0
  * Added Support for Keen 1 version 1.34
  * Added Support for Keen 6 version 1.50
- Drop not longer needed patch:
  * 0001-build-resolve-compile-error-with-gcc-13.patch
* Tue Mar 28 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-resolve-compile-error-with-gcc-13.patch
* Sat Dec 10 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.0
  * More collision fixes, especially relevant in Keen 2.
  * Improved the Video engine a bit. Changing resolutions on the
    fly now work better.
  * Fixed some ledge grabbing issues.
* Mon Jul  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.3
  * No changes; version bump only
* Wed Jun 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.2
  * Added option for showing/hiding achievements
- Update to version 3.1.1
  * Collision fixes
  * F10 is working again
* Sat May 21 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.0
  * New main menu theme
  * Collision fixes
  * Updated runtime
* Mon Nov 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.9
  * Bug fixes with changed aspect ratio and resolutions
  * Multiplayer fixes
  * Many gameplay bug fixes
* Sun Sep 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  * New Engine with parallax scrolling feature
  * Added support for Cosmos the Cosmic Adventure
  * Many bug fixes, some general improvements
* Wed Jun 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.2
  * Improved carmack decompression routine.
  * Sliding through entrances/doors improved.
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.1
  * More Keen Galaxy engine fixes
  * Menu fixes
* Fri May 14 2021 Simon Lees <sflees@suse.de>
- %%cmake_build is now the recommended way to build cmake projects
- DCMAKE_INSTALL_PREFIX is set by the cmake macro
* Tue Apr 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.0
  * Remove legacy SDL 1.2 code at many parts
  * More stable graphics engine
  * SDL2 is not an option anymore
  * Improved logging
  * Open GL 2.1 is minimum now
  * Lots of OpenGL fixes
  * Boost library now is optional
  * C++17
* Tue Apr  6 2021 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * fix-icons.patch
* Tue Apr  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.9
  * Add appdata
* Sun Mar 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.8
  * More logging. Code cleanups
* Sun Feb 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.7
  * Now you can configure the base url. If http does not work on
    your side, feel free to set it to https.
  * Some Memory cleanups
* Mon Feb  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.6
  * Foot improvement on some mods. With Eight Accumlators now it
    works correclty.
* Sun Jan  3 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.5
  * Achivement System improved. Now you can see what achivements
    you got and how much is yet missing
  * Quit Menu now shows three ways to quit your current game
* Mon Dec 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.4
  * Virtual pad control improvements
* Fri Dec 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.3
  * Smarter Game store. Catalogue entries can be read later at
    runtime and in the background
* Sun Dec 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.2
  * Disc color now is white
  * Touch buttons give feedback when pressed/touched
  * Improved overall direction and buttons control
  * No more ugly vpad background
* Sat Dec 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.1
  * Bugfix release
* Fri Dec  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.7.0
  * More Keen Dreams fixes
  * More Lua support and remaining python code is now completely
    removed
  * Added sound buffer amplifier for improving the sound/music
    quality hopefully on certain systems
* Mon Oct 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.6.3
  * We have eight control presets which got some standard names.
  * Bug fixes in the Keen dreams engine
* Mon Oct 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.6.2
  * More sounds are now played
  * Collision fixes
  * AI fixes
  * Added 5 control presets which can be saved and loaded.
* Sat Oct 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.6.1
  * More lua support. Oblivion v1.4 fully working
  * More crash fixes, especially for Keen 6 DEMO
* Fri Oct 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.6.0
  * Fixing mute music after saving a game
  * Added PC Speaker Volume option
* Sun Aug 30 2020 Martin Hauke <mardnh@gmx.de>
- Drop patch (fixed by upstream):
  * commandergenius-set-gskit-linker-language.patch
* Sun Aug 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.5.5
  * Improved controller configuration for multiplayer
* Tue Aug 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.5.4
  * Level swap when Hardmode in Episode 1 works once again
* Sun Aug 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.5.3
  * Secret Ending In Keen 5 is unlockable
  * Crash fixes with older save game files
* Thu Aug 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.5.2
  * Improved blinking sprites for home-made creations
  * Keen dreams improvements with level signs
  * Now you can remove gameplay and menu bindings
  * Collision detection improvements
  * Splitting up the control settings a bit better
  * Since you can unbind Super Run option got removed.
* Sun Aug  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.5.1
  * Ceilick Ai improvements
  * Small bug fix with sprite export in Galaxy Keen.
- Add patch:
  * commandergenius-set-gskit-linker-language.patch
* Sun Jul 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.4.6
  * New Export graphics feature
  * Super Run option. The run button now only works when you
    enable that option
* Tue Jul  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.5.2
  * Black screen fixes
  * Reduced probability of the slug doing the squat action.
* Fri Jun 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.5
  * QED Fixes
  * Improved Savegame menu style and overall functionality
  * Minor GUI improvements
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.4
  * Boost libraries are now optional, thanks to TinyXML2 code
  * AutoGun working in Keen 4-6
  * Better Analog controls handling in Keen 4-6
* Sat May 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.3
  * Finally, loading the game list is much faster. Enjoy!
  * Integer scaling improvements
  * Fixes to the load of high-res tiles in keen5 and 6
  * Some bug fixes
* Sat May 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.2
  * SDL_Cursor now should work as intended
  * Finally added some scroll arrows to list views
  * More loading feedback especially for galaxy audio
  * Adding some emscripten code so GsKit is compatible with WASM
  * Some resolution and rendering improvements
  * Keen dreams freezes less especially when using cheat codes
  * Fixed broken Messie to Player interaction
  * Added Quicksave (F6) and Quickload (F9) so dying is less
    tedious
  * Added Integer scaling of video resoltion
  * Added 640x360 game resolution which scales nice to 1920x1080
* Thu Apr  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.1
  * Added an achievement system for keen4se.
* Sun Mar 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.0
  * Fixed problem with some dialogs in vorticon keen engine
  * Improved the code for save game menus
  * Added option where you can choose whether you type your save
    game or a timestamp is automatically entered instead
  * Disabled button cannot be triggered anymore as it should be
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.3.9
  * Virtualpad improvements
  * Android improvements
  * Settings improvements for horizontal border size
  * Crash fixes, bug fixes
* Fri Nov  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.3.6
  - Scrollbar improvements
  - Crash fixes, bug fixes
  - Search path issues fixed
  - New font added for better scalibility
  - Updated GsKit, many code cleanups in the library
  - Settings fixups
  - Modern setting makes the dithering effect a bit smoother when
    Galaxy is shown
  - Brought back the info menu for help and ordering info
  - More log messages for better feedback
- Use %%cmake macros
- Run spec-cleaner
* Tue Aug  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.2.3
  * Tweaked Game menu design
  * Optimized compilation process
  * Reduce some compiler warnings
  * Overall code modernization
  * AI improvements
  * Collision improvements with switches
- Take the source from the upstream authors gitlab instance.
  The github mirror wasn't up to date.
* Fri Jul 27 2018 jengelh@inai.de
- Update to new upstream release 2.2.2
  * Player selection in Keen 4 Plus. Play as Lindsey, Council or
    Kyle.
  * Different character in Multiplayer mode.
  * Added support for Mod, Midi and FLAC.
  * Sprite selection screen when Single player mode (Galaxy).
* Sat Mar 17 2018 jengelh@inai.de
- Update to new upstream release 2.0.7
  * Integration of the KeenDreams GPLed engine
  * Many AI fixes in Keen 4, 5 and 6
  * Platform sprite corrections in Keen 5
  * Many collision fixes
  * Smoother scrolling with vsync
- Remove commandergenius-nocurrentdate.diff (no longer needed)
* Sun May  3 2015 dap.darkness@gmail.com
- Updated to 1.8.1.1 to resolve openSUSE:Factory build failures:
  * Dosbox fusion;
  * A lot of dosbox fixes;
  * Better mouse controls;
  * New submenu for mods;
  * More fixes and AI improvements;
  * More native resolutions if higher modes are used,
    especially in the launcher;
  * Some improved physics;
  * Shorter game names;
  * Last window size is now saved automatically;
  * Heavy engine independent code cleanups which will make CG more
    flexible for new game engines besides Commander Keen;
  * New GsLib will take more work at low level functions and will
    as wrapper for SDL and GUI elements;
  * Multiple selection problem should be fixed now;
  * Even more smooth effects readded;
  * New pump event concept will solve a lot of deadlocks we
    previously had on the android versions;
  * Added Scrollbar for a bigger list of games;
  * Wormmoutch bites again;
  * More effects readded;
  * Many bug fixes especially Keen 1,2 and 4.
- Switched from tarball to _service.
- Added commandergenius-nocurrentdate.diff vs. useless rebuilds.
- General spec clean up.
* Thu Jan 30 2014 jengelh@inai.de
- Initial package (version 1.6.5.5) for build.opensuse.org
